@@ -6,6 +6,7 @@
 //using namespace RcppArmadillo;
 //using namespace arma;
 
+// [[Rcpp::interfaces(r, cpp)]]
 
 ////////////////////////////////////////////////////////////////////////////////
 /* -----------------------------------------------------------------------------
@@ -811,3 +812,8 @@ getwd()
 source("./../../fnorm.R")
 */
 
+
+// pull in other functions
+#include "ridgePchordal.h"
+
+
